Opcode

Enum Opcode 

#[repr(u8)]
pub enum Opcode {
Show 24 variants OP_0 = 0, OP_1 = 81, OP_2 = 82, OP_3 = 83, OP_16 = 96, OP_RETURN = 106, OP_DUP = 118, OP_EQUAL = 135, OP_EQUALVERIFY = 136, OP_VERIFY = 105, OP_HASH160 = 169, OP_CHECKSIG = 172, OP_CHECKSIGADD = 186, OP_NUMEQUAL = 156, OP_NUMEQUALVERIFY = 157, OP_CHECKLOCKTIMEVERIFY = 177, OP_CHECKSEQUENCEVERIFY = 178, OP_SUCCESS = 80, OP_NOP = 97, OP_DROP = 117, OP_SWAP = 124, OP_IF = 99, OP_ELSE = 103, OP_ENDIF = 104,
}
Bitcoin/Tapscript opcodes.

Variants



OP_0 = 0

Push empty byte vector.



OP_1 = 81

Push the number 1 (OP_TRUE).



OP_2 = 82

Push the number 2.



OP_3 = 83

Push the number 3.



OP_16 = 96

Push the number 16.



OP_RETURN = 106

Return immediately (marks output as unspendable/data carrier).



OP_DUP = 118

Duplicate the top stack item.



OP_EQUAL = 135

Pop and check equality.



OP_EQUALVERIFY = 136

OP_EQUAL + OP_VERIFY.



OP_VERIFY = 105

Verify top stack item is nonzero, fail if not.



OP_HASH160 = 169

Pop two items, fail if not equal.



OP_CHECKSIG = 172

BIP-340 Schnorr signature check (replaces legacy OP_CHECKSIG).



OP_CHECKSIGADD = 186

BIP-342: Schnorr sig check + accumulate counter.



OP_NUMEQUAL = 156

Check that the top stack item equals the required number of signatures.



OP_NUMEQUALVERIFY = 157

OP_NUMEQUAL + OP_VERIFY.



OP_CHECKLOCKTIMEVERIFY = 177

Check locktime.



OP_CHECKSEQUENCEVERIFY = 178

Check sequence.



OP_SUCCESS = 80

Mark remaining script as always-succeeding (BIP-342).



OP_NOP = 97

No operation.



OP_DROP = 117

Drop top stack item.



OP_SWAP = 124

Swap top two stack items.



OP_IF = 99

If top stack item is true, execute following script.



OP_ELSE = 103

Else branch for OP_IF.



OP_ENDIF = 104

End if block.